package com.aucma.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.BaseStoreInfoMapper;
import com.aucma.base.domain.BaseStoreInfo;
import com.aucma.base.service.IBaseStoreInfoService;

/**
 * 仓库信息Service业务层处理
 * 
 * @author Yinq
 * @date 2023-09-20
 */
@Service
public class BaseStoreInfoServiceImpl implements IBaseStoreInfoService 
{
    @Autowired
    private BaseStoreInfoMapper baseStoreInfoMapper;

    /**
     * 查询仓库信息
     * 
     * @param objId 仓库信息主键
     * @return 仓库信息
     */
    @Override
    public BaseStoreInfo selectBaseStoreInfoByObjId(Long objId)
    {
        return baseStoreInfoMapper.selectBaseStoreInfoByObjId(objId);
    }

    /**
     * 查询仓库信息列表
     * 
     * @param baseStoreInfo 仓库信息
     * @return 仓库信息
     */
    @Override
    public List<BaseStoreInfo> selectBaseStoreInfoList(BaseStoreInfo baseStoreInfo)
    {
        return baseStoreInfoMapper.selectBaseStoreInfoList(baseStoreInfo);
    }

    /**
     * 新增仓库信息
     * 
     * @param baseStoreInfo 仓库信息
     * @return 结果
     */
    @Override
    public int insertBaseStoreInfo(BaseStoreInfo baseStoreInfo)
    {
        return baseStoreInfoMapper.insertBaseStoreInfo(baseStoreInfo);
    }

    /**
     * 修改仓库信息
     * 
     * @param baseStoreInfo 仓库信息
     * @return 结果
     */
    @Override
    public int updateBaseStoreInfo(BaseStoreInfo baseStoreInfo)
    {
        return baseStoreInfoMapper.updateBaseStoreInfo(baseStoreInfo);
    }

    /**
     * 批量删除仓库信息
     * 
     * @param objIds 需要删除的仓库信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseStoreInfoByObjIds(Long[] objIds)
    {
        return baseStoreInfoMapper.deleteBaseStoreInfoByObjIds(objIds);
    }

    /**
     * 删除仓库信息信息
     * 
     * @param objId 仓库信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseStoreInfoByObjId(Long objId)
    {
        return baseStoreInfoMapper.deleteBaseStoreInfoByObjId(objId);
    }
}
